/// <reference types="node" />
import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CodeartifactClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CodeartifactClient";
import { PublishPackageVersionRequest, PublishPackageVersionResult } from "../models/models_0";
/**
 * The input for {@link PublishPackageVersionCommand}.
 */
declare type PublishPackageVersionCommandInputType = Omit<PublishPackageVersionRequest, "assetContent"> & {
    /**
     * For *`PublishPackageVersionRequest["assetContent"]`*, see {@link PublishPackageVersionRequest.assetContent}.
     */
    assetContent: PublishPackageVersionRequest["assetContent"] | string | Uint8Array | Buffer;
};
/**
 * This interface extends from `PublishPackageVersionRequest` interface. There are more parameters than `assetContent` defined in {@link PublishPackageVersionRequest}
 */
export interface PublishPackageVersionCommandInput extends PublishPackageVersionCommandInputType {
}
/**
 * The output of {@link PublishPackageVersionCommand}.
 */
export interface PublishPackageVersionCommandOutput extends PublishPackageVersionResult, __MetadataBearer {
}
/**
 * <p>Creates a new package version containing one or more assets (or files).</p>
 *          <p>The <code>unfinished</code> flag can be used to keep the package version in the <code>Unfinished</code> state until all of it’s assets have been uploaded (see <a href="https://docs.aws.amazon.com/codeartifact/latest/ug/packages-overview.html#package-version-status.html#package-version-status">Package version status</a> in the <i>CodeArtifact user guide</i>). To set the package version’s status to <code>Published</code>, omit the <code>unfinished</code> flag when uploading the final asset, or set the status using <a href="https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html">UpdatePackageVersionStatus</a>. Once a package version’s status is set to <code>Published</code>, it cannot change back to <code>Unfinished</code>.</p>
 *          <note>
 *             <p>Only generic packages can be published using this API.</p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CodeartifactClient, PublishPackageVersionCommand } from "@aws-sdk/client-codeartifact"; // ES Modules import
 * // const { CodeartifactClient, PublishPackageVersionCommand } = require("@aws-sdk/client-codeartifact"); // CommonJS import
 * const client = new CodeartifactClient(config);
 * const command = new PublishPackageVersionCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link PublishPackageVersionCommandInput} for command's `input` shape.
 * @see {@link PublishPackageVersionCommandOutput} for command's `response` shape.
 * @see {@link CodeartifactClientResolvedConfig | config} for CodeartifactClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>
 *         The operation did not succeed because of an unauthorized access attempt.
 *       </p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>
 *         The operation did not succeed because prerequisites are not met.
 *       </p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p> The operation did not succeed because of an error that occurred inside CodeArtifact. </p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>
 *       The operation did not succeed because the resource requested is not found in the service.
 *     </p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>
 *         The operation did not succeed because it would have exceeded a service limit for your account.
 *       </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>
 *       The operation did not succeed because too many requests are sent to the service.
 *     </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>
 *       The operation did not succeed because a parameter in the request was sent with an invalid value.
 *     </p>
 *
 *
 */
export declare class PublishPackageVersionCommand extends $Command<PublishPackageVersionCommandInput, PublishPackageVersionCommandOutput, CodeartifactClientResolvedConfig> {
    readonly input: PublishPackageVersionCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: PublishPackageVersionCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CodeartifactClientResolvedConfig, options?: __HttpHandlerOptions): Handler<PublishPackageVersionCommandInput, PublishPackageVersionCommandOutput>;
    private serialize;
    private deserialize;
}
export {};
